# Generated by Django 5.2 on 2024-09-04 15:02

import django.db.models.deletion
import lnschema_core.ids
import lnschema_core.models
import lnschema_core.users
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("clinicore", "0003_alter_project_uid"),
        (
            "lnschema_core",
            "0064_alter_artifact_version_alter_collection_version_and_more",
        ),
    ]

    operations = [
        migrations.RemoveField(
            model_name="biosample",
            name="project",
        ),
        migrations.CreateModel(
            name="ClinicalTrial",
            fields=[
                ("created_at", models.DateTimeField(auto_now_add=True, db_index=True)),
                ("updated_at", models.DateTimeField(auto_now=True, db_index=True)),
                ("id", models.AutoField(primary_key=True, serialize=False)),
                (
                    "uid",
                    models.CharField(
                        default=lnschema_core.ids.base62_8, max_length=8, unique=True
                    ),
                ),
                ("name", models.CharField(db_index=True, default=None, max_length=255)),
                ("title", models.TextField(default=None, null=True)),
                ("objective", models.TextField(default=None, null=True)),
                ("description", models.TextField(default=None, null=True)),
                (
                    "_previous_runs",
                    models.ManyToManyField(related_name="+", to="lnschema_core.run"),
                ),
                (
                    "artifacts",
                    models.ManyToManyField(
                        related_name="clinical_trials", to="lnschema_core.artifact"
                    ),
                ),
                (
                    "collections",
                    models.ManyToManyField(
                        related_name="clinical_trials", to="lnschema_core.collection"
                    ),
                ),
                (
                    "created_by",
                    models.ForeignKey(
                        default=lnschema_core.users.current_user_id,
                        on_delete=django.db.models.deletion.PROTECT,
                        to="lnschema_core.user",
                    ),
                ),
                (
                    "run",
                    models.ForeignKey(
                        default=lnschema_core.models.current_run,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        to="lnschema_core.run",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
            bases=(lnschema_core.models.CanCurate, models.Model),
        ),
        migrations.AddField(
            model_name="biosample",
            name="clinical_trial",
            field=models.ForeignKey(
                default=None,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="biosamples",
                to="clinicore.clinicaltrial",
            ),
        ),
        migrations.DeleteModel(
            name="Project",
        ),
    ]



# Generated by Django 5.2 on 2024-09-02 14:25

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("clinicore", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="biosample",
            name="patient",
            field=models.ForeignKey(
                default=None,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="biosamples",
                to="clinicore.patient",
            ),
        ),
        migrations.AddField(
            model_name="biosample",
            name="project",
            field=models.ForeignKey(
                default=None,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="biosamples",
                to="clinicore.project",
            ),
        ),
        migrations.AddField(
            model_name="biosample",
            name="medications",
            field=models.ManyToManyField(
                related_name="biosamples", to="clinicore.medication"
            ),
        ),
    ]



from pathlib import Path

import nbproject_test as test


def test_notebooks():
    docs_folder = Path(__file__).parents[1] / "docs/"
    for check_folder in docs_folder.glob("./**"):
        test.execute_notebooks(check_folder, write=True)



# Generated by Django 5.2 on 2024-09-09 13:14

import django.db.models.deletion
import lnschema_core.models
import lnschema_core.users
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("bionty", "0039_alter_cellline_source_alter_cellmarker_source_and_more"),
        ("clinicore", "0004_remove_biosample_project_clinicaltrial_and_more"),
        ("lnschema_core", "0066_alter_artifact__feature_values_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="biosample",
            name="created_by",
            field=models.ForeignKey(
                default=lnschema_core.users.current_user_id,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lnschema_core.user",
            ),
        ),
        migrations.AlterField(
            model_name="biosample",
            name="run",
            field=models.ForeignKey(
                default=lnschema_core.models.current_run,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lnschema_core.run",
            ),
        ),
        migrations.AlterField(
            model_name="clinicaltrial",
            name="created_by",
            field=models.ForeignKey(
                default=lnschema_core.users.current_user_id,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lnschema_core.user",
            ),
        ),
        migrations.AlterField(
            model_name="clinicaltrial",
            name="run",
            field=models.ForeignKey(
                default=lnschema_core.models.current_run,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lnschema_core.run",
            ),
        ),
        migrations.AlterField(
            model_name="medication",
            name="created_by",
            field=models.ForeignKey(
                default=lnschema_core.users.current_user_id,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lnschema_core.user",
            ),
        ),
        migrations.AlterField(
            model_name="medication",
            name="run",
            field=models.ForeignKey(
                default=lnschema_core.models.current_run,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lnschema_core.run",
            ),
        ),
        migrations.AlterField(
            model_name="medication",
            name="source",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="bionty.source",
            ),
        ),
        migrations.AlterField(
            model_name="patient",
            name="created_by",
            field=models.ForeignKey(
                default=lnschema_core.users.current_user_id,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lnschema_core.user",
            ),
        ),
        migrations.AlterField(
            model_name="patient",
            name="run",
            field=models.ForeignKey(
                default=lnschema_core.models.current_run,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lnschema_core.run",
            ),
        ),
        migrations.AlterField(
            model_name="treatment",
            name="created_by",
            field=models.ForeignKey(
                default=lnschema_core.users.current_user_id,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lnschema_core.user",
            ),
        ),
        migrations.AlterField(
            model_name="treatment",
            name="run",
            field=models.ForeignKey(
                default=lnschema_core.models.current_run,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lnschema_core.run",
            ),
        ),
    ]



"""Basic clinical entities [`source <https://github.com/laminlabs/clinicore/blob/main/clinicore/models.py>`__].

Install and mount `clinicore` in a new instance:

>>> pip install clinicore
>>> lamin init --storage ./test-clinicore --schema bionty,clinicore

Import the package:

>>> import clinicore as cc

Registries:

.. autosummary::
   :toctree: .

   Biosample
   ClinicalTrial
   Medication
   Patient
   Treatment
"""

__version__ = "0.6.0"  # denote a pre-release for 0.1.0 with 0.1rc1

from lamindb_setup import _check_instance_setup


def __getattr__(name):
    if name != "models":
        _check_instance_setup(from_module="clinicore")
    return globals()[name]


if _check_instance_setup():
    import lamindb

    del __getattr__  # delete so that imports work out
    from .models import (
        Biosample,
        ClinicalTrial,
        Medication,
        Patient,
        Treatment,
    )
